@@ -1,5 +1,5 @@
 package API::Google;
-$API::Google::VERSION = '0.08';
+$API::Google::VERSION = '0.09';
 # ABSTRACT: Perl library for easy access to Google services via their API
 
 
@@ -89,7 +89,7 @@ sub api_query {
     'Authorization' => 'Bearer '.$self->get_access_token_from_storage($params->{user})
   );
   my $http_method = $params->{method};
-  if ($http_method eq 'get') {
+  if ($http_method eq 'get' || $http_method eq 'delete') {
     return $self->{ua}->$http_method($params->{route} => \%headers)->res->json;
   } elsif (($http_method eq 'post') && $payload) {
     return $self->{ua}->$http_method($params->{route} => \%headers => json => $payload)->res->json;
@@ -113,7 +113,7 @@ API::Google - Perl library for easy access to Google services via their API
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -181,7 +181,7 @@ Pavel Serikov <pavelsr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Pavel Serikov.
+This software is copyright (c) 2017 by Pavel Serikov.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
